@@ -21,7 +21,7 @@ config = {
 			"analysis": {
 			  "filter": {
 				"postag_filter": {
-				  "type": "pattern_capture",
+				  "type": "pattern_capture",   # add _contact_VERB as a term , => _contact_VERB with  ( _([a-z]+)_(VERB|NOUN|ADJ|ADV)
 				  "preserve_original": "false",
 				  "patterns": [
 					"(^([^_]+)_[a-z]+[,\\.$]?)",
