@@ -11,10 +11,12 @@ def likelihood(a,b,c,d, minus=None):  #from: http://ucrel.lancs.ac.uk/llwizard.h
 	try:
 		if a is None or a <= 0 : a = 0.000001
 		if b is None or b <= 0 : b = 0.000001
+		if c is None or c <= 0 : c = 0.000001
+		if d is None or d <= 0 : d = 0.000001
 		E1 = c * (a + b) / (c + d)
 		E2 = d * (a + b) / (c + d)
 		G2 = round(2 * ((a * ln(a / E1)) + (b * ln(b / E2))), 2)
-		if minus or  (minus is None and a/c < b/d): G2 = 0 - G2
+		if minus or  (minus is None and a * d < b * c): G2 = 0 - G2 #if minus or  (minus is None and a/c < b/d): G2 = 0 - G2
 		return G2
 	except Exception as e:
 		print ("likelihood ex:",e, a,b,c,d)
